@@ -34,7 +34,7 @@ using namespace std::chrono_literals;
 
 WaylandConfig::WaylandConfig(QObject *parent)
     : QObject(parent)
-    , m_outputManagement(nullptr)
+    , m_outputManagement(std::make_unique<WaylandOutputManagement>(12))
     , m_registryInitialized(false)
     , m_blockSignals(true)
     , m_kscreenConfig(new Config)
@@ -43,6 +43,7 @@ WaylandConfig::WaylandConfig(QObject *parent)
     , m_tabletModeAvailable(false)
     , m_tabletModeEngaged(false)
 {
+    connect(m_outputManagement.get(), &WaylandOutputManagement::activeChanged, this, &WaylandConfig::handleActiveChanged);
     initKWinTabletMode();
     setupRegistry();
 }
@@ -112,10 +113,7 @@ void WaylandConfig::setupRegistry()
     auto globalAdded = [](void *data, wl_registry *registry, uint32_t name, const char *interface, uint32_t version) {
         auto self = static_cast<WaylandConfig *>(data);
         if (qstrcmp(interface, WaylandOutputDevice::interface()->name) == 0) {
-            self->addOutput(name, std::min(8u, version));
-        }
-        if (qstrcmp(interface, WaylandOutputManagement::interface()->name) == 0) {
-            self->m_outputManagement = new WaylandOutputManagement(registry, name, std::min(9u, version));
+            self->addOutput(name, std::min(11u, version));
         }
         if (qstrcmp(interface, WaylandOutputOrder::interface()->name) == 0) {
             self->m_outputOrder = std::make_unique<WaylandOutputOrder>(registry, name, std::min(1u, version));
@@ -163,6 +161,33 @@ void WaylandConfig::setupRegistry()
     }
 }
 
+void WaylandConfig::handleActiveChanged()
+{
+    if (m_outputManagement->isActive()) {
+        if (!m_registry) {
+            setupRegistry();
+        }
+        return;
+    }
+    // the compositor went away, clean up all the Wayland resources
+    if (!m_registry) {
+        return;
+    }
+    qDeleteAll(m_initializingOutputs);
+    m_initializingOutputs.clear();
+    auto outputs = std::move(m_outputMap);
+    m_screen->setOutputs({});
+    qDeleteAll(outputs);
+
+    m_outputOrder.reset();
+    wl_registry_destroy(m_registry);
+    m_registry = nullptr;
+
+    if (!m_blockSignals) {
+        Q_EMIT configChanged();
+    }
+}
+
 int s_outputId = 0;
 
 void WaylandConfig::addOutput(quint32 name, quint32 version)
@@ -237,7 +262,7 @@ bool WaylandConfig::isReady() const
             && m_registryInitialized
             && m_initializingOutputs.isEmpty()
             && m_outputMap.count() > 0
-            && m_outputManagement != nullptr;
+            && m_outputManagement->isActive();
     // clang-format on
 }
 
@@ -316,18 +341,21 @@ WaylandOutputDevice *WaylandConfig::findOutputDevice(struct ::kde_output_device_
     return nullptr;
 }
 
-void WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
+bool WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
 {
     newConfig->adjustPriorities(); // never trust input
 
     // Create a new configuration object
     auto wlConfig = m_outputManagement->createConfiguration();
+    if (!wlConfig) {
+        return false;
+    }
     bool changed = false;
 
     if (m_blockSignals) {
         // Last apply still pending, remember new changes and apply afterwards
         m_kscreenPendingConfig = newConfig;
-        return;
+        return true;
     }
 
     for (const auto &output : newConfig->outputs()) {
@@ -335,7 +363,7 @@ void WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
     }
 
     if (!changed) {
-        return;
+        return false;
     }
 
     // We now block changes in order to compress events while the compositor is doing its thing
@@ -347,9 +375,10 @@ void WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
         Q_EMIT configChanged();
         tryPendingConfig();
     });
-    connect(wlConfig, &WaylandOutputConfiguration::failed, this, [this, wlConfig] {
+    connect(wlConfig, &WaylandOutputConfiguration::failed, this, [this, wlConfig](const QString &errorMessage) {
         wlConfig->deleteLater();
         unblockSignals();
+        Q_EMIT configFailed(errorMessage);
         Q_EMIT configChanged();
         tryPendingConfig();
     });
@@ -357,6 +386,7 @@ void WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
     // Now block signals and ask the compositor to apply the changes.
     blockSignals();
     wlConfig->apply();
+    return true;
 }
 
 #include "moc_waylandconfig.cpp"
