@@ -427,6 +427,26 @@ void Doctor::parseOutputArgs()
                     }
                     output->setBrightness(brightness / 100.0);
                     m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "colorPowerTradeoff") {
+                    if (ops[3] == "preferEfficiency") {
+                        output->setColorPowerPreference(Output::ColorPowerTradeoff::PreferEfficiency);
+                    } else if (ops[3] == "preferAccuracy") {
+                        output->setColorPowerPreference(Output::ColorPowerTradeoff::PreferAccuracy);
+                    } else {
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: only allowed values for colorPowerTradeoff are \"preferEfficiency\" and \"preferAccuracy\"";
+                        qApp->exit(9);
+                        return;
+                    }
+                    m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "dimming") {
+                    const uint32_t dimming = ops[3].toUInt();
+                    if (dimming > 100) {
+                        qCWarning(KSCREEN_DOCTOR) << "Wrong input: Allowed range for dimming is 0 to 100";
+                        qApp->exit(9);
+                        return;
+                    }
+                    output->setDimming(dimming / 100.0);
+                    m_changed = true;
                 } else {
                     cerr << "Unable to parse arguments: " << op << Qt::endl;
                     qApp->exit(2);
@@ -457,10 +477,10 @@ void Doctor::configReceived(KScreen::ConfigOperation *op)
 
     parseOutputArgs();
 
-    if (m_changed) {
-        applyConfig();
-        m_changed = false;
+    if (const auto error = applyConfig()) {
+        cout << "applying config failed! " << *error << "\n";
     }
+    qApp->exit(0);
 }
 
 void Doctor::showOutputs() const
@@ -617,13 +637,23 @@ void Doctor::showOutputs() const
                 cout << "EDID";
                 break;
             }
+            cout << endl << yellow << "\tColor power preference: " << cr;
+            switch (output->colorPowerPreference()) {
+            case Output::ColorPowerTradeoff::PreferEfficiency:
+                cout << "prefer efficiency and performance";
+                break;
+            case Output::ColorPowerTradeoff::PreferAccuracy:
+                cout << "prefer accuracy";
+                break;
+            }
             cout << endl;
         } else {
             cout << cr << "incapable" << endl;
         }
         cout << yellow << "\tBrightness control: ";
         if (output->capabilities() & Output::Capability::BrightnessControl) {
-            cout << cr << "supported, set to " << std::round(output->brightness() * 100) << "%" << endl;
+            cout << cr << "supported, set to " << std::round(output->brightness() * 100) << "%"
+                 << " and dimming to " << std::round(output->dimming() * 100) << "%" << endl;
         } else {
             cout << cr << "unsupported" << endl;
         }
@@ -735,15 +765,17 @@ void Doctor::setWcgEnabled(OutputPtr output, bool enable)
     m_changed = true;
 }
 
-void Doctor::applyConfig()
+std::optional<QString> Doctor::applyConfig()
 {
     if (!m_changed) {
-        return;
+        return std::nullopt;
     }
     auto setop = new SetConfigOperation(m_config, this);
-    setop->exec();
-    qCDebug(KSCREEN_DOCTOR) << "setop exec returned" << m_config;
-    qApp->exit(0);
+    if (setop->exec()) {
+        return std::nullopt;
+    } else {
+        return setop->errorString();
+    }
 }
 
 #include "moc_doctor.cpp"
